#!/usr/bin/python2.7

import rospy
from sensor_msgs.msg import Joy
import sys

from geometry_msgs.msg import Twist
from geometry_msgs.msg import Vector3


class TeleRobot:
    def __init__(self):
        # Initialize ROS
        rospy.init_node('control_node', anonymous=True)

        # Subscribe and Publish to Topics
        rospy.Subscriber("joy", Joy, self.array_callback)

        self.pub_twist = rospy.Publisher("/arm_control", Twist, queue_size=10, latch=True)

        # Initialize global variables and constants
        self.left_vertical = 0
        self.left_horizontal = 0

        self.right_vertical = 0
        self.right_horizontal = 0

        self.left_button = 0
        self.right_button = 0

        rospy.loginfo("Arm Control Node is loaded...")
        self.r = rospy.Rate(10)
        self.updater()

    def array_callback(self, joy_array):

        self.left_vertical = joy_array.axes[3]
        self.left_horizontal = joy_array.axes[0]

        self.right_vertical = joy_array.axes[4]
        self.right_horizontal = joy_array.axes[1]

        self.left_button = joy_array.buttons[4]
        self.right_button = joy_array.buttons[5]

    def updater(self):
        while not rospy.is_shutdown():
            self.pub_twist.publish(Twist(Vector3(self.left_vertical, self.left_horizontal, self.left_button), Vector3(self.right_vertical, self.right_horizontal, self.right_button )))

            self.r.sleep()


def main(args):
    try:
        TeleRobot()
    except KeyboardInterrupt:
        rospy.loginfo("Shutting down control node.")


if __name__ == '__main__':
    main(sys.argv)
