#!/usr/bin/python2.7

import rospy
from geometry_msgs.msg import Twist
import serial
import sys

import time

# ser = serial.Serial('/dev/rfcomm1', 9600, serial.EIGHTBITS, serial.PARITY_NONE, serial.STOPBITS_ONE)
ser = serial.Serial('/dev/ttyUSB1', 57600, serial.EIGHTBITS, serial.PARITY_NONE, serial.STOPBITS_ONE)
time.sleep(3)


class SerialRobot:
    def __init__(self):
        # Initialize ROS
        rospy.init_node('serial_node', anonymous=True)

        # Subscribe and Publish to Topics
        rospy.Subscriber("/arm_control", Twist, self.array_callback)

        # Initialize global variables and constants
        self.left_vertical = 0
        self.left_horizontal = 0
        self.right_vertical = 0
        self.right_horizontal = 0

        self.left_button = 0
        self.right_button = 0

        rospy.loginfo("Serial Node is loaded...")
        self.r = rospy.Rate(10)
        self.updater()

    def array_callback(self, twist_array):
        self.left_vertical = twist_array.linear.x  # w and s
        self.left_horizontal = twist_array.linear.y  # a and d

        self.right_vertical = twist_array.angular.x  # i and k
        self.right_horizontal = twist_array.angular.y  # j and l

        self.left_button = twist_array.linear.z  # t
        self.right_button = twist_array.angular.z  # y

    def updater(self):
        while not rospy.is_shutdown():

            if self.left_vertical == 1:
                value = 'w'
            elif self.left_vertical == -1:
                value = 's'
            elif self.left_horizontal == 1:
                value = 'a'
            elif self.left_horizontal == -1:
                value = 'd'
            elif self.right_vertical == 1:
                value = 'i'
            elif self.right_vertical == -1:
                value = 'k'
            elif self.right_horizontal == 1:
                value = 'j'
            elif self.right_horizontal == -1:
                value = 'l'
            elif self.left_button == 1:
                value = 't'
            elif self.right_button == 1:
                value = 'y'
            else:
                value = chr(0)

            rospy.loginfo(value)

            ser.write(bytearray([value]))

            self.r.sleep()


def main(args):
    try:
        SerialRobot()
    except KeyboardInterrupt:
        rospy.loginfo("Shutting down serial node.")


if __name__ == '__main__':
    main(sys.argv)
